@@ -55,7 +55,7 @@ sub new {
 		$self->{increment} = 1;
 	}
 	
-	bless $self;
+	bless $self, $class;
 
 	return $self;
 }
@@ -93,7 +93,7 @@ Stefan Hornburg (Racke), <racke@linuxia.de>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2010-2014 Stefan Hornburg (Racke) <racke@linuxia.de>.
+Copyright 2010-2015 Stefan Hornburg (Racke) <racke@linuxia.de>.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
